
# q-expansion of newform 418.2.f.h, downloaded from the LMFDB on 09 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 418
weight = 2
poly_data = [1936, -24464, 115472, 67728, 147848, 44616, 77528, 21224, 48880, 10376, 24392, 5704, 7288, 1120, 1002, 50, 103, -3, 11, -1, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[-22296914615172419224488011576150009732855120, 121882588724593567914767600344448311094709000, -71509999456807755647941495749014399210374944, 76577716407292814428619432886509525536289760, -38005323634943263023688578895548062958345800, 50674018317685090259392550752277020695584708, -28763838356752280536057497972413222473046960, 27142975920048211993006810404836333963597604, -15641875878401038213980375380248483177158608, 6670397463812532519860247619683944405292602, -4961615592137145064328870751170402405358624, 1522525271405162518875987792081963416025862, -683845058570754227219749279297607808786008, 287689743708760188279370985988374687796541, -93946014690053042544487720719997525373894, 38039801294206829756836388350764025760353, -12426791344905951572733980984337463025683, 4503465948257994288818585137162737485321, -1277826882118872543767223242393183840452, 256974214344781729293779863534686881769], 109632609093474887143076573867313390151356808], [[13067615374604895509232562363774679315362240, 3025430519989105247210991309068070596474192, -18889956378480277251309984273704138161022384, 27633416902344733035477367991370485418444656, 9995252305631085008485667791775176101786240, -13179597983940521557519675629543530630469048, 2408612201277582716416805450480886034171800, 10257017831116709429942316932890327230463260, -2233905394873121986471323091207252278699608, 7670305881168428983584490822177416189086130, -535028011158253549572669633009327412564856, 3014572729095622638897165977388221625215286, 135625005787699426462904331721148730107616, 489598172829272439561664421337102275182125, -19091301363177575421305300929414027701132, 54633015431977248301006666415229887768144, -6908577628654211172524055178835971307250, 6715399148960119854338280347259789308792, -1298402719343482519747776929124665428675, 598591088358719114813407205268069901502], 109632609093474887143076573867313390151356808], [[9996656638116859506906326836692926160804112, -136497851464804117882972885809259571408782240, -187575927360676775712659910070650637359649280, -169273732942644201800080429241182876409476944, -97132712651999376596269561384603524229354200, -74882518753734943463289334875233533384935852, -61884041156654627996817841792770664802668096, -32389503970331731092867145784831038886459004, -34341302104032049814966725526418894929946512, -21444732169465079337271304151361249408846988, -14261553556429546449311136148711134446359712, -6655838411720629848312166995665434842234106, -2340767915751492403564759004536733857486784, -780204461540439455191945231418021933531079, -197442763295180507569123260622046734496474, -66648899677643226622854447054676719762777, -15439988922438472434819397687377061917385, -5969749065245043069284769005484708519049, -908403352760352154016918840720346865686, -764578777161086055201651093965285318455], 109632609093474887143076573867313390151356808], [[585910388049595982017311600726055875745762816, -57155615186046468544280913453683360137173136, 343524455518386753351673177750148347152784848, -431516583680155668707939908542874118152361800, 77433762480078942396534807969401442472058360, -201859347337279311633316303851061054644216228, 90274534091541262010926772392358839979910248, -154794951453079576550695469984422899910652844, 49993956679560817706034621000567494987443188, -75202496964014927422650597589329242119356970, -2320715557688052987994345879142686624620694, -25931887002710075406058021049996502124651960, -2340301091004816625723157086874960458535808, -3713152862361505661572504964464058088093113, 46255294477285810509817824780807445301558, -422508305476872797485851600379258672091480, 36368562772994825170424142506597596295774, -41032677769165637278354326196864733727070, 4368324128077381060092855180341576924745, -3772972580436844064186643269973055055786], 109632609093474887143076573867313390151356808], [[388709460614356561286469324311535123029018152, -56944345898011204853971673875699795652901792, 327217966811051605169511028254989237861929256, -307859220041639159680815227034216338687949360, 107274361399448425239090373315403814127958176, -122585091530980721110833549573138305087717172, 91535488313877088387356918777333417248973492, -120746112066215465333872279060074259905561792, 54399443786287057251084994420023416986270680, -70672143546560993510822050988273254646342900, 9125781786510918714628417064911223440062582, -25633699744747721051395058785773017508436284, -224840595689355811665076702625911829023550, -4146742481323522738900613788697623497817622, 246128810761220877277334702949665445335127, -457489140846002219868607830692635069756820, 64616242873159202579443306912888960206618, -55526138711908978227525589615229008404096, 10526716775238685153881790099113161531504, -4716343054823007800699216261874193377119], 109632609093474887143076573867313390151356808], [[-18219694377782364084241768292164967677100396, 3593266997640071243749719847473370667139568, -20348890181089999269481591694605741448488776, 17195329733017342295898224214633437763645512, -10015792285846664372864443241909050198660876, 10083827718178867368381846477350428248432930, -7277042075792758100171470189046238020226508, 6825023860351843377274370478238016894668356, -3719700193132534507806439503805321593118646, 3488241325053800293965331690208071904844222, -768799626685076274834290409079950751084533, 1203771206418460996297053329814026728232448, -48349514182871962732273240865659519499486, 199323495266920875911649902547162593650831, -17648778172288090804893590885920532158158, 22094435067764213069626813081814389800161, -3684973736867528733717848571061443331272, 2730705336623380983445779414789864991586, -554266045910107000914435399033665874387, 220773145257601962634316850766711907784], 4983300413339767597412571539423335915970764], [[10176463037691075022974755781958049922257552, 783822794776291445641114131396376654735874704, 518991481282715824054084408577721359373805920, 860555073515791444972863884809900914220349216, 305260014913973478463357866975384149908921524, 462204700164879774614293930116701026060323672, 141980950503075649571472456106096878161720612, 286736227967230444803386795659451038907273472, 75021854729950892479657692197603915650842580, 140211165497001053211944981293656307439300776, 36108797845511211783949402675673932167247874, 39972810053455868481216262096384898041340280, 6563394252186556525303043401405665167054119, 5371332200998224529222087873414563270201908, 324827015331487738681385615357696506973627, 547286907169358167275393604391597823571736, -9520937873985627654227101092696478713602, 57707588796606144806893775867384700052073, -4398983535915804185968972272095110425762, 5163562313076890241170623366060395744217], 109632609093474887143076573867313390151356808], [[168152570253632784863877006633129927399687952, -798303015539831772211073641954380672202090864, -429517127566271156969327892222333791787574864, -987949374711199798901129972889711800870154080, -314328734116880613520288271921987276670862488, -520889985299945732903305351026132408367379720, -133000765593787372330363418402209772867288900, -332164194398327301992301719961716717637638808, -62365632717437147361352010772102579976305710, -165176182049052164324986234290649811844546136, -35486294056413842229213647929104945117980074, -49056927086216679949201824236042210180202304, -7070179316611576202143123722995356832878675, -6782392233880793949517910408626846194019812, -282857051060917780346528518599612036698856, -702138114604017970186446536309410335709270, 26964803138533821573190391448150304776812, -75546217347780388822205517632389888811415, 7348392418216619687764110905564908390842, -6749801329857900572950703700296838489340], 109632609093474887143076573867313390151356808], [[18989818407135500454929157552164437153959784, 1738179307988448149429833173920579711139577104, 956479029884528447519520944306078473739298144, 1667883275446503593406988092862746180082706840, 557036764055578639051876016117170102066935420, 943068457007240218790566723614476908131586964, 272051513965106760420761767742906246719768572, 580609050616395715827420148657841480342021020, 130957770830491318645597709843004934409343252, 272183182668684861523369548017752837179581890, 62486434239907830103439887023700412500007972, 73703863788158485928258453604564438983717368, 10833747300951713875152915522996030830569384, 9728460681147414831876302182020079236860670, 480363020792433074776555549594210679403827, 1010177505563136641702690587308749813443174, -35525752093788821132471596125181701136470, 106565648471608271515323118422694476510830, -7995165424878721210575754697065827787148, 8833154939684755506954876205025643306119], 109632609093474887143076573867313390151356808], [[-91172908123827120450896630115490861086235184, 1243900959760638277642677337040705717554941136, 946075537611546163970051593885227598900832576, 1537365990884530530518140134424758115982326496, 555447831382615070966799503492403663686259464, 805440957233950003755564635599435330431049752, 280559997498974622302573264272053917858296396, 501881183718202441215376397550033604488115656, 138827025492353664969409528277691737201784392, 250996064804822926531158584085230224079789656, 67838004765535320945760305570861516331102342, 74167943753387747996978897448287472063223928, 12679946192193404525605908931592903528582385, 10035029305941201949833753586682548968329292, 655859833105386788724131800608590482937374, 1018973140354090846819036017027318517855418, -12603672839630411830164423437367955665604, 107570559425641083580057464402544864518701, -8310618254166602781559847812990354891196, 9930762334031189680868685975758396992922], 109632609093474887143076573867313390151356808], [[-28583738670738646296214073432871172998390256, -2125325548954931889194455055901162626838906632, -1467835278539702467711760092971854721957103632, -2365030887595194500326340927079555622811661432, -866771718738533401558772540747530738743357424, -1235121149029468534431495577240205954410140860, -455334533193139077847073756330250699835261768, -770781251840062532108891871079784119638347796, -217287955858645848466834320773265069261248460, -378732368831484968561111430732327414871275046, -100058025168237153579664199474423805216233982, -105117208162210094683072611309682130034021236, -17282414030998821501631095814608932079944024, -13738321417231497980626100638806090812405066, -900750814025536155549962773335298965022133, -1413617336883505109730886210521543929853368, 29477773584437831910258550598483950274422, -148945288077267691771630192491619508968310, 9680541609041365987456972514921043298248, -12687587596224527647994604356792877896601], 109632609093474887143076573867313390151356808], [[42720546873738759769979002733295737805784320, 2665004346913988488382355183709751605852568104, 2201290175325982796920089509560285410366187056, 3486383068948221518260215769674116785181928776, 1379406692632002501631360931761230098775668428, 1830254742690513984254510613549263564472030892, 716385829349363875993826139844267939079764780, 1133001280071004527807201290985112659608490556, 352716488964992593368072942269739651811962296, 565567606759161051414888228766401736536153378, 162610254793743118162759182590007987409635876, 167775849657859450938102226461243785934605306, 30168778210040358345254411214236369666050105, 22691469845478748085890028229228243099302466, 1639607235657289693254286295128325310989338, 2285010894468906797977032591645472908652296, -7378339431104921695531211478367853178238, 240693362097365666906055075150538741240613, -17945596995522260812994412836856967756386, 22674604840652492908974901169286379429204], 109632609093474887143076573867313390151356808], [[-43890060350761084379682941905343324628741040, -2736608962674621458569662212755049721078352312, -2279416713793824030910494143343194136379592784, -3484650153231307152708809426373560687846363976, -1473217755956698965283246589446993667169068604, -1782727232090447014041767363729440937400564292, -792886225572711884180200813778552798329682496, -1104786244070628252658749883489554409878996476, -385963811920402242133910918108972631526744072, -561529640392450445669606037460806380959777230, -173352343274564188680364044342807018592232880, -169566035451561600521143210216708371185351854, -32253543239763943475900568605846453729695035, -22976059876250864389666030521851088332243282, -1842055865241761339073345309807544259894718, -2294109455901179775224313103880892715213438, -15284658141565782427799759238239814642328, -241387932676291830349733868645196739662065, 17364212260200644934862786728613551488332, -23364042156150916651643871958510106134166], 109632609093474887143076573867313390151356808], [[-600851707533385906374942015027385696536815888, 2809123346557399811374186275589200962431394152, 1874166244688664930827659786908244070255999816, 3793285021001913321651142312017885796861231760, 1186325257070389682109668723723180859163308256, 1976024629482511977491819881711302856436190660, 603023945678161593946662614608905141592704244, 1228248509486151835126124881458336737024305648, 312434454397192235562273475464002632383753626, 615056396459602044900482061025180777425137716, 164667112627619279674475405622395733860425476, 186460700043176472096249512133060047626699942, 32079817980391113215315846608574881871453437, 25503469155402858241554630445586923162382341, 1631473799152018550410044804591713502926708, 2587653120132692450495730638394787870794514, -27036714889722342352516215678188072663468, 271036710349222359787760984111685477280067, -21619962470323206044030920548480217808147, 25735810978271390444103654208854241619726], 109632609093474887143076573867313390151356808], [[-582745591550070910701372703743955876961896848, 2706388928804801042390491256282580593106898008, 1966737771165570177804371487006238542139451024, 3685019719402285108099824181537464550472287312, 1277107456425341688103037347831899252157346960, 1907140604650485448266615436785852769127215356, 638421528025429347583128462057322581385432180, 1214221882588406290248316360150474990909171440, 320466966127369057104812858137753517943709562, 620122931323464442222065989874586101586809596, 166247896084000381935808139815637149925840522, 188005097764337859602500871170393442102256922, 32130089606758406374987606082220500428610293, 25684380967351325986215565196907266645516235, 1636078698058591275963967050669731179151195, 2610290272085226378298790320969336614142766, -33773956440571871869755495312557739977026, 275624567181802974173838509427742026119277, -22317530751837180309776057827871731844611, 25896713065385550943963805302346209975407], 109632609093474887143076573867313390151356808], [[444219251863541756400972851400633066706227040, -2091017119847044135820153022611829582164653416, -1276384115571300023962717238777796740488667812, -2695570238792846383778907215394410042104910988, -793154237997578992359033037500253288051673436, -1406599449706551503041474856797193781367471324, -394984313813539496738465567697747584111232812, -885607857356821600140251740044611062044556858, -185836560045741849175981484374643175430725498, -445084194343136438391713951415065958881559545, -101565366557592232257804642163346940249720737, -132215658961993683642094990820671308005968710, -19668486678070154026434800450853952140068553, -18121714859850800475500474804868260552829130, -863209433812315122265959458253559697637383, -1868709492666067492137635043835762879907703, 64950001163536710640287392133951461728488, -201679941817771887336004130097302717523485, 18695018157526352399273626183965825002114, -17956792622362102589903727894297974667748], 54816304546737443571538286933656695075678404], [[-489979140163317042316476123561523318176426144, 6685167003981912555385486026957163613509191800, 4596944744323985306207765773979299083165602288, 8278373438101259651740461186438039353550421696, 2982951146375802585854956376847616087620440904, 4312321567944706725764582626242472152970025872, 1472103611878764167117409831356244803112491412, 2703558220417907925002762280845361133881323328, 730081243458453367728301785357037644348468284, 1346232851369153830673756777771485905852322440, 363147576005885748253049541329040710901443598, 399311364300707405713750886080487761647437478, 68758774714564264998001888434355211840432728, 54080670756777558679477086591567052330920559, 3530125745128078335451825160156723115584174, 5502073153005956940249108387410958027939830, -61666727332386360488985613004458863134894, 576071358792066245490640907742016735252244, -43858351244871256516191304358741700934157, 53654637932956975326618001782641735438210], 109632609093474887143076573867313390151356808], [[77506142892121455312723048798532775298231936, -611188505470853575745703993740230167082395224, -400053123055692649414644334773250015542595912, -755824405235766967831984802633053867139735176, -254677535072946307884770978715671389661950304, -398343355962682958263047891470921106606062328, -124684718079536536233987261281584235501965528, -248466513906779530064608331198022547500462412, -62150883596929376836133444236238838645870216, -124189082171160454832316010237365330900175646, -31228271475782854603615857932890295069798184, -36935440031814841115858966307197463992988034, -5973189737661442901489618172890416048292258, -5065844633538656550180878382690638947228456, -287082394443612477520634583883696401922023, -515676104038835359936747580793486163719476, 10721731271561043554539200133445845187750, -55160915193680599657540579096751130338222, 4850966337934693158436639508674723184708, -5069047928723769568623615691672258119305], 9966600826679535194825143078846671831941528]]

hecke_ring_character_values = [[343, [-1, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0]], [287, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0], [1, 1, 0, 0, 0, 0, 0, 0, -1, -1, 0, 0, -1, 0, 0, 1, 0, 0, 0, 0], [1, -1, 0, 1, 0, 1, 0, -1, -1, 0, 0, 1, 1, 0, 1, 0, 0, -1, 1, 1], [-1, 1, -1, 0, 0, 0, 0, 1, 0, 1, 0, 0, -1, 0, 0, 0, 1, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 2, 0, -1, 0, 0, 0, -1, 0, 0, -1, 0, 1], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0], [0, -1, 1, 0, 0, 0, -1, 1, 1, 1, 0, 0, 0, 1, -1, -1, -1, 0, 0, 0], [3, -1, 1, -1, -1, 0, -1, 0, -3, 0, 0, 2, 2, 1, 0, -2, 0, 0, 0, 0], [0, 0, -1, 0, 0, -1, 1, 0, 1, -1, -1, -1, 0, 0, 0, 1, -2, 0, 0, -1], [2, 1, -1, -1, 1, 0, 0, -1, -2, -1, 1, 1, 0, 0, 1, 0, 1, 1, -1, 0], [0, -1, 0, 0, -2, 0, 2, 2, -1, 1, 0, 2, 1, 0, 1, -3, 2, 0, -1, 0], [-1, 0, 0, 0, 0, -2, 1, 0, -1, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [-2, -1, 2, 2, 0, 1, -1, -2, -1, 3, 0, -1, 1, 0, 1, 1, -1, -1, 2, 0], [0, -2, -1, 0, -2, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, -3, 2, -2, 0, 0], [2, 0, 1, 1, -1, 0, 0, -2, -2, -1, 0, 0, -1, 0, 2, 1, 0, 0, 0, -1], [-1, 0, 0, 0, 0, -2, 0, 0, 5, 0, 0, -1, -1, 3, 0, 0, 0, 1, -2, -1], [3, -4, 4, 2, 0, 0, 0, -3, -1, -1, 0, 0, 0, 1, 2, 2, -1, 0, 0, 0], [1, 0, 0, -2, 2, 1, 0, 0, 0, 0, -1, 1, 3, 2, 1, 0, 0, -2, 1, 2], [1, -2, 0, 0, 0, 0, 0, 0, -1, 1, -1, 1, 2, 0, 0, -2, -1, -3, 3, 2], [1, -2, 1, 0, -1, 0, 1, -1, 1, 2, -1, -1, 1, 0, 0, -1, 3, 0, 0, 0], [-1, 0, 0, 3, -3, 1, 0, 0, -1, 0, -2, -1, -2, -1, 5, 0, 0, 0, 1, 0], [1, -1, 1, -1, 0, 0, 0, 1, 3, 3, 0, 0, 0, 0, 1, 1, 0, 0, -1, -1], [-1, 1, -1, 0, 0, 0, -2, 1, -4, -6, 2, 4, -1, 0, 0, 2, 0, 2, 0, 0], [0, -1, 1, 0, -1, 0, 1, 0, -2, 0, -1, 2, 0, 0, 0, -1, -1, -1, 0, 0], [-1, -2, -1, 2, 1, 0, 0, -1, 1, 2, 0, -2, 0, 0, 1, 0, 0, -1, 1, 0], [0, -1, 2, 2, -2, 1, 2, 0, -1, 1, -2, -4, 1, -2, 1, -1, 0, -1, 5, 0], [-2, -1, 1, -1, 0, -1, 1, -1, 0, 0, 0, 0, 0, -2, -2, -2, 2, 0, -2, -2], [-5, 2, -3, -3, 1, -2, 2, 3, 2, 3, 0, 0, -2, 0, -2, -1, 2, 2, -3, 0], [0, 1, 0, 2, -2, 1, 0, 0, 7, 0, 0, 0, 1, -1, 0, 0, 0, 1, 1, -1], [1, 0, 0, -4, 0, 0, 0, 0, -4, -4, 0, 0, 0, -1, -2, -2, 1, 0, 0, 0], [-1, -1, 0, 0, 0, 2, 0, 0, 4, 0, -4, -1, 1, -2, -1, 0, 0, -1, 2, 1], [3, -2, 2, 3, -2, 0, 0, -1, -3, -6, -2, 5, -1, 0, 1, 1, -2, 1, -1, -1], [-1, -1, 0, -3, 3, 2, 0, 0, 2, 0, 3, -1, 3, 0, -1, 0, 0, -1, 2, 1], [3, 1, 2, 2, 1, -1, 0, -2, 1, -4, -1, -1, -1, -1, -1, 3, -1, 1, -4, 0], [-6, 0, 0, 0, 0, -1, -3, -1, 0, 6, -1, -9, 0, -1, 0, 1, -4, 1, 1, 0], [0, -2, -1, 0, -2, 1, -1, 0, -6, -3, 1, 6, 0, 0, 0, -2, -1, 1, 0, 1], [-4, 4, -1, 0, 0, 2, -2, 4, -2, -2, 2, 2, -4, 0, 0, -1, -1, 0, 0, 2], [9, -3, 4, 4, -1, 0, 0, -5, -3, -6, 0, 0, 3, 0, 3, 2, 0, 0, -1, 0], [-6, 2, -3, -3, 3, -2, -5, 3, 2, 4, 4, 4, -2, 4, -2, -1, -1, 2, -1, 0], [4, 4, 0, -2, 2, -2, 0, 0, -1, 0, 0, 4, -1, 1, -4, 0, 0, -1, -2, 1], [-3, -1, 2, 1, -2, 0, -3, 4, 3, 5, 1, -5, 0, 3, -4, 0, 1, -1, 1, 1], [-5, 1, 0, -3, 3, -3, 0, 0, 14, 0, 1, -5, -3, 1, -8, 0, 0, 1, -3, -1], [3, -2, 2, 2, 0, 1, 1, -2, -5, -5, 0, 0, 0, 2, 3, 3, -2, 0, 2, 2], [6, 0, 0, 4, 0, 2, 3, -6, 2, 2, 0, 0, 0, -3, 4, 4, 3, 0, 1, 1], [5, -4, 2, 0, 1, -2, 2, -5, 0, 3, -2, 0, 5, 0, 0, -2, 1, -2, 0, -2], [-11, 2, -3, -3, 5, 0, -5, 4, 2, 9, 2, -6, -2, 2, -2, -2, -3, 0, -3, 0], [-5, -3, 0, 3, 0, 0, 2, 0, 5, 1, 1, -1, 0, -2, 0, 0, 1, -1, 1, -1], [-2, 3, 3, 0, 1, -2, -3, 2, 0, 8, 3, 0, -2, 0, 0, 3, 0, 3, 0, -2], [4, -4, 6, 0, 0, 0, 0, -4, -3, 0, 0, 3, 4, 0, 0, -5, -1, -2, 0, 0], [-6, 8, -3, -3, -2, 0, 1, 9, 8, -2, -1, -6, -8, -1, -8, -1, 0, 0, 0, 0], [-2, 3, -3, 0, 0, 5, 2, 0, -3, -3, 0, 0, 0, 0, 3, 3, 0, 0, 1, 1], [-3, 0, -1, 0, -3, 2, -2, 3, -1, -4, 2, 1, -3, 0, 0, 1, 4, -2, 0, 2], [7, 2, -1, -4, 1, 0, 1, 1, -7, -1, 3, 3, 2, -1, -1, -2, 3, 0, 0, -1], [-1, 0, 0, 7, 0, 3, -3, 0, -8, -8, 0, 0, 0, 1, 3, 3, -1, 0, 0, 0], [2, -3, 0, 6, -6, 0, 0, 0, -3, 0, 2, 2, -2, 2, 5, 0, 0, 2, 0, -2], [4, 8, -6, -8, 6, 0, -1, 2, -4, -8, 3, 8, 0, 1, -2, 0, 3, 3, -3, 2], [-2, 6, -3, 0, 4, 1, -1, 2, 5, -4, 1, -5, -2, 0, 0, 5, -1, -2, 0, 1], [-1, -4, 0, -2, 2, 0, 0, 0, -2, 0, 1, -1, -2, -1, -4, 0, 0, -4, 0, 4], [-2, 1, 2, 2, -2, -2, 1, 4, 1, 1, -2, -12, -1, -2, -1, -3, -1, 2, 1, 0], [-4, 1, -1, -3, 1, 0, 0, 1, 4, -3, -3, 5, 2, 0, -1, -2, -3, -1, 1, 3], [-1, -2, 2, 5, 0, 1, -7, -2, 1, 1, 0, 0, 0, 3, 0, 0, -3, 0, 3, 3], [-7, 3, 3, 3, -1, 0, -4, 3, 3, 4, -1, 0, -3, -1, -3, 0, -5, 0, 3, 0], [6, -8, 0, 8, -8, 4, 0, 0, -2, 0, -1, 6, 0, 0, 5, 0, 0, -1, 4, 1], [-1, -2, 1, 0, -3, -5, 3, 1, 7, 6, -3, -7, -1, 0, 0, 2, -2, 1, 0, -5], [14, -3, 3, -3, 0, 0, 5, -5, -5, -5, 0, 0, 0, -5, -2, -2, 5, 0, -3, -3], [8, 1, -5, 0, 5, 0, 2, 1, -8, -10, 9, 9, -1, -2, -1, 1, 9, 1, -1, 0], [1, -3, 0, -3, 3, -4, 0, 0, -1, 0, 0, 1, -1, 0, -1, 0, 0, 4, -4, -4], [2, -1, 4, 4, 1, 2, -5, -8, -1, -1, 2, -6, 1, 2, 1, 7, -3, -2, 4, 0], [-11, -2, 2, 2, 0, 4, -1, 1, 2, 2, 0, 0, 0, -1, -2, -2, 1, 0, 5, 5], [4, -4, 0, -5, 0, 0, 0, -2, -4, 6, 2, 3, 9, 0, 2, -9, 2, -4, 4, 1], [-1, 4, 5, -4, -5, 0, 2, 4, 1, 0, -2, 0, 0, -2, -4, 0, -2, -3, 3, -1], [-8, 3, -3, -2, 0, -6, -2, 2, 11, 11, 0, 0, 0, -2, -3, -3, 2, 0, -1, -1], [0, -5, 0, -2, 2, -4, 0, 0, 2, 0, 2, 0, -1, -2, -4, 0, 0, 3, -4, -3], [7, -7, 9, 0, 0, -2, -2, -7, 2, 0, 2, -2, 7, 0, 0, 0, -6, 1, 0, -2], [7, 0, 2, -1, -2, 0, -2, -1, -7, -4, 2, 5, 1, 2, 1, -1, 2, -1, 1, -2], [-6, 5, -5, 2, 0, -1, 6, 0, 1, 1, 0, 0, 0, -2, 2, 2, 2, 0, 1, 1], [8, -1, 0, -2, 2, -5, 0, 0, 0, 0, 2, 8, 3, -4, -6, 0, 0, 2, -5, -2], [1, -5, 3, 0, -4, 1, 2, -1, 8, 4, -2, -8, 1, 0, 0, -5, 3, 1, 0, 1], [-5, -4, 4, 8, 0, -2, 1, -4, 3, 3, 0, 0, 0, 4, 6, 6, -4, 0, 0, 0], [-2, 2, 0, 0, -4, -1, 0, 1, 2, 0, 3, -11, -2, 3, -2, 1, 3, 1, -4, 0], [5, -5, 1, 0, 0, -2, -4, -5, -18, -11, 4, 18, 5, 0, 0, -2, -5, 0, 0, -2], [7, 5, -6, -2, 6, 0, 5, 1, -7, -8, 1, 5, -3, -5, -1, 3, 1, -4, 4, 3], [11, -3, 3, 4, 0, -3, 0, -5, -5, -5, 0, 0, 0, 0, 5, 5, 0, 0, -5, -5], [8, -4, -1, -1, 6, -1, 6, -2, -4, -4, -3, 5, 4, -3, 4, -2, 3, 1, -3, 0], [2, -4, 6, 0, -2, 2, -1, -2, 11, 0, 1, -11, 2, 0, 0, 4, 4, 2, 0, 2], [6, -2, 0, 4, -4, 1, 0, 0, 10, 0, 3, 6, 4, -2, 2, 0, 0, 1, 1, -1], [-2, -2, 2, -4, 0, -6, -6, 1, 7, 7, 0, 0, 0, 4, -6, -6, -4, 0, -7, -7], [-10, 0, 0, 3, 0, 6, -3, -2, -1, -1, 0, 0, 0, 4, 6, 6, -4, 0, 1, 1], [3, -1, 0, 2, -2, -5, 0, 0, 9, 0, -2, 3, -3, 6, 4, 0, 0, 0, -5, 0], [-8, 5, 0, -3, 3, 6, 0, 0, -1, 0, 1, -8, 5, 0, 0, 0, 0, -2, 6, 2], [-5, 4, -2, -2, 1, 1, 3, 10, 4, 1, 2, -2, -4, 2, -4, -6, 5, -1, 3, 0], [-10, 9, -6, -6, 6, 0, -6, 2, 10, 4, -1, -7, -3, 6, -2, 3, -1, 1, -1, -1], [7, -2, -7, -2, 7, 0, 3, 0, -7, -7, 5, 11, 4, -3, 0, -4, 5, 0, 0, -1], [3, 3, 3, 3, 5, 2, 0, -4, 3, -6, -3, -3, -3, -3, -3, 7, -3, -2, 1, 0], [-4, 2, -5, -5, -3, 1, 9, 0, 2, 2, -9, -7, -2, -9, -2, 2, 0, -1, 3, 0], [-5, -4, -2, 0, 2, 0, -6, 1, 5, 10, 6, -6, 4, 6, -1, -4, 6, 1, -1, -2], [-6, 1, 0, 4, -4, -4, 0, 0, 3, 0, -4, -6, -3, 1, 0, 0, 0, 4, -4, -4], [-8, 4, -6, 0, -4, 3, 4, 8, 11, 9, -4, -11, -8, 0, 0, -3, 3, -3, 0, 3], [-13, 0, 2, 2, -6, 4, -7, 1, 0, 13, 1, -19, 0, 1, 0, -1, -6, -4, 6, 0], [-9, -4, -3, 0, 3, 0, -5, 3, 9, 6, -2, -2, 4, 5, -3, -4, -2, 4, -4, 0], [-6, 9, -7, 0, 3, 2, 2, 6, -2, -11, -2, 2, -6, 0, 0, 9, 2, 1, 0, 2], [12, -6, 10, 10, 0, 4, 4, -6, -6, -6, 0, 20, 6, 0, 6, 0, 4, -4, 0, 0], [-20, 2, -2, 4, 0, -1, 1, 2, 13, 13, 0, 0, 0, 1, 1, 1, -1, 0, 0, 0], [-4, -5, 0, 10, -10, 6, 0, 0, 3, 0, -2, -4, 1, -4, 3, 0, 0, -1, 6, 1], [-14, 12, -9, -6, 9, 0, 2, 6, 14, -2, -2, -4, -6, -2, -6, 6, -2, -2, 2, 5], [-8, -2, 2, -6, 0, 2, -5, -3, -2, -2, 0, 0, 0, 5, 2, 2, -5, 0, -1, -1], [0, 14, 0, -9, 9, 3, 0, 0, -6, 0, -2, 0, -4, -2, -8, 0, 0, -4, 3, 4], [1, 3, 3, -5, -3, 0, 2, 6, -1, 3, -7, -1, 2, -2, -6, -2, -7, -1, 1, 0], [5, 0, -1, 0, 5, 0, 7, -5, -3, 9, -7, 3, 5, 0, 0, -4, 3, -2, 0, 0], [-12, -1, 4, 4, -5, 0, -2, 8, -1, 13, 3, -4, 1, 3, 1, -9, 1, 0, 0, 0], [-1, 4, -4, 0, 0, 1, -3, -2, 8, 8, 0, 0, 0, 4, 4, 4, -4, 0, -1, -1], [-7, 1, -2, -2, -1, 1, -8, 8, 1, 6, 4, -1, -1, 4, -1, -7, -4, -1, 1, 0], [8, 4, -4, -7, 4, 0, 3, 2, -8, 0, -1, 3, 3, -3, -2, -3, -1, -1, 1, 3], [3, 1, -1, -1, 10, -3, -11, -7, 1, -4, 5, -3, -1, 5, -1, 8, -6, 3, -3, 0], [2, 7, 0, -4, 4, -2, 0, 0, 3, 0, -3, 2, -4, -3, -5, 0, 0, -4, -2, 4], [-7, 4, -1, 0, -3, 4, 3, 7, 13, 22, -3, -13, -7, 0, 0, -1, 3, -1, 0, 4], [-6, 4, -11, -1, 11, 0, -6, 4, 6, -4, 0, 1, -3, 6, -4, 3, 0, 3, -3, -2], [11, 1, -1, 5, 0, 5, -2, -5, -18, -18, 0, 0, 0, 1, 1, 1, -1, 0, 5, 5], [-4, 3, -3, -3, 0, 0, 0, 2, 3, 3, 0, 0, 0, 7, 0, 0, -7, 0, -1, -1], [2, -8, 9, 0, -6, -2, 4, -2, 4, 15, -4, -4, 2, 0, 0, 1, -4, -3, 0, -2], [11, 1, 0, 7, -7, -1, 0, 0, -8, 0, 1, 11, -2, 1, 0, 0, 0, 4, -1, -4], [-3, 3, -3, 6, 0, -1, 1, -8, -7, -7, 0, 0, 0, -2, 5, 5, 2, 0, -6, -6], [4, 0, 11, 0, 4, -2, 0, -4, -5, -6, 0, 5, 4, 0, 0, -5, -1, 0, 0, -2], [17, -2, 13, 13, -2, 4, -5, -11, -2, -15, 2, -1, 2, 2, 2, 9, -3, -4, -1, 0], [-5, 8, 0, -4, 4, 0, 0, 0, 2, 0, 2, -5, 2, 2, 1, 0, 0, 3, 0, -3], [-22, -1, 2, 7, -2, 0, 4, -1, 22, 8, -6, -14, -6, -4, 1, 6, -6, 0, 0, 1], [-6, 0, 0, -5, 0, 5, -7, -1, 8, 8, 0, 0, 0, -3, 2, 2, 3, 0, 0, 0], [5, 4, 1, -3, -1, 0, 1, 1, -5, -5, 2, 4, -1, -1, -1, 1, 2, 0, 0, 4], [6, -2, 5, 0, 4, -4, -2, -6, -15, -2, 2, 15, 6, 0, 0, -1, 3, 0, 0, -4], [-2, 3, 0, 4, -4, -2, 0, 0, -3, 0, 2, -2, -1, 2, -3, 0, 0, 0, -2, 0], [11, 3, 1, 1, 9, 2, -6, -4, 3, -14, 3, -17, -3, 3, -3, 7, -3, -2, 0, 0], [-5, 7, -8, 0, 2, 1, -3, 5, 9, -9, 3, -9, -5, 0, 0, 4, 3, 0, 0, 1], [3, -5, 2, 0, -2, 2, 3, -3, 13, -4, -3, -13, 3, 0, 0, 0, 4, -2, 0, 2], [0, -4, 4, -4, 0, -9, 0, 1, 11, 11, 0, 0, 0, 7, -3, -3, -7, 0, 1, 1], [5, 2, 2, 2, 15, 1, -3, -1, 2, -7, 1, 9, -2, 1, -2, 3, -2, -1, 1, 0], [9, -4, 0, 6, -6, -2, 0, 0, 9, 0, -5, 9, 1, 5, 1, 0, 0, 1, -2, -1], [-1, -3, 0, 3, -3, -5, 0, 0, 0, 0, -3, -1, -8, -1, 4, 0, 0, 7, -5, -7], [1, 3, 0, 2, -2, -1, 0, 0, -17, 0, 4, 1, 1, 0, 6, 0, 0, 5, -1, -5], [-8, 1, -6, -6, 9, -4, 9, 0, 1, 7, -5, -15, -1, -5, -1, 1, 4, 4, -1, 0], [-15, 7, -1, 0, 1, 0, -1, 6, 15, -12, -4, 5, -7, 1, -6, 7, -4, 2, -2, 1], [3, -10, -2, 0, -7, 1, -7, -3, -2, -9, 7, 2, 3, 0, 0, -3, 8, 2, 0, 1], [-2, -10, 8, 0, -12, -1, 2, 2, 18, 10, -2, -18, -2, 0, 0, -9, -5, -2, 0, -1], [1, 11, -12, -8, 12, 0, 5, -2, -1, -5, 2, 2, -3, -5, 2, 3, 2, 3, -3, -2], [1, -3, 3, 3, -6, -2, -7, 0, -3, 2, 0, 12, 3, 0, 3, -3, -7, 2, 6, 0], [16, -3, 0, 1, -1, 6, 0, 0, -6, 0, -1, 16, 5, 1, 8, 0, 0, 0, 6, 0], [17, 7, -7, -5, 0, 9, 8, -5, -10, -10, 0, 0, 0, -10, 2, 2, 10, 0, 5, 5], [-9, -9, 9, 12, 0, -7, -7, -2, -9, -9, 0, 0, 0, 4, -4, -4, -4, 0, -4, -4], [4, 10, 0, -5, 5, -7, 0, 0, -8, 0, 4, 4, 1, -1, -7, 0, 0, 6, -7, -6], [-6, 1, -1, -1, -7, -2, -2, 2, 1, 5, -2, 6, -1, -2, -1, -1, -4, 2, -2, 0], [13, 0, 0, 2, 0, -3, 5, -8, -6, -6, 0, 0, 0, -5, 1, 1, 5, 0, -1, -1], [18, 1, -3, -3, 3, -2, 1, -4, 1, -19, -4, 6, -1, -4, -1, 5, -3, 2, -2, 0], [0, -13, 0, 12, 0, 0, -4, -5, 0, 10, 3, -9, 1, 4, 5, -1, 3, 4, -4, 1], [-2, 8, 0, -16, 16, -9, 0, 0, 10, 0, 6, -2, 0, 5, -1, 0, 0, 8, -9, -8], [6, 2, 1, 0, 8, 3, -1, -6, -15, -13, 1, 15, 6, 0, 0, 8, 5, 5, 0, 3], [8, 9, 0, -9, 9, -4, 0, 0, -5, 0, 3, 8, -2, 3, 0, 0, 0, -1, -4, 1], [-9, -10, 0, 2, -2, -1, 0, 0, 11, 0, -4, -9, 2, 7, -4, 0, 0, 2, -1, -2], [-9, 11, 0, 0, 2, -1, 1, 9, 18, 10, -1, -18, -9, 0, 0, 4, 1, 8, 0, -1], [-18, 4, 0, 4, -4, 1, 0, 0, -4, 0, -2, -18, -4, 4, -4, 0, 0, -2, 1, 2], [11, -11, 11, 8, 0, -1, 0, 0, -6, -6, 0, 0, 0, 5, 2, 2, -5, 0, 4, 4], [3, 5, -3, -8, 3, 0, -7, -3, -3, 8, 5, -5, 3, 7, 3, -3, 5, -1, 1, -2], [-12, -1, 1, -2, 0, 2, -2, 8, 8, 8, 0, 0, 0, 4, 1, 1, -4, 0, 1, 1], [7, -3, -2, -2, -3, -1, 9, 3, -3, -4, 1, 3, 3, 1, 3, -6, 10, 1, -3, 0], [7, -4, 2, 0, 3, 3, -7, -7, 1, 0, 7, -1, 7, 0, 0, 2, -4, -1, 0, 3], [-18, 0, 7, 5, -7, 0, -13, 0, 18, 10, 3, -15, -5, 13, 0, 5, 3, -1, 1, 5], [16, 4, -4, -10, 0, -9, 1, 7, -8, -8, 0, 0, 0, 4, -6, -6, -4, 0, -4, -4], [7, 1, 1, 4, -1, 0, -5, 2, -7, 8, -1, -13, -5, 5, -2, 5, -1, -2, 2, 1]]
